@@ -4,6 +4,7 @@ import 'script-loader!../vpython_libraries/glow.min.js';
 import 'script-loader!../vpython_libraries/plotly.min.js';
 import '../style/jquery-ui.custom.css'
 import '../style/ide.css'
+import img from '../vpython_data/flower_texture.jpg'
 
 // Ensure downstream JupyterLab webpack places the fonts and images in predictable locations
 import '!!file-loader?name=/vpython_data/[name].[ext]!../vpython_data/earth_texture.jpg'
@@ -40,7 +41,12 @@ export function createWebsocket(msg, serviceUrl) {
         var uri = msg.content.data.wsuri
         var url;
     
-        url = serviceUrl + port + uri;
+        if (document.location.hostname.includes("localhost")){
+           url = "ws://localhost:" + port + uri;
+        }
+        else {
+           url = serviceUrl + port + uri;
+        }
         ws = new WebSocket(url);
         ws.binaryType = "arraybuffer";
 		
@@ -53,13 +59,13 @@ export function createWebsocket(msg, serviceUrl) {
         ws.onclose = function(evt) {
             ws = null
             isopen = false
-            // console.log("***WebSocket Connection Closed***");
+            console.log("***WebSocket Connection Closed***");
         };
  
         // Open Websocket callback
         ws.onopen = function(evt) {
             isopen = true
-            // console.log("***WebSocket Connection Opened***");
+            console.log("***WebSocket Connection Opened***");
         };
     }
 }
@@ -78,13 +84,15 @@ export function setupWebsocket(msg,serviceUrl) {
 	wscheckfontsloaded(msg,serviceUrl)
 }
 
-// Old datadir value for a source extension npm package. (used prior to JupyterLab 3.0)
-//var datadir = '/static/lab/vpython_data/'
-//window.Jupyter_VPython = "/static/lab/vpython_data/" // prefix used by glow.min.js for textures
+//var datadir = './static/lab/vpython_data/'
+//window.Jupyter_VPython = "./static/lab/vpython_data/" // prefix used by glow.min.js for textures
 
-// New datadir value for a prebuilt extension (new in JupyterLab 3.0) 
-var datadir = '/lab/extensions/vpython/static/vpython_data/'
-window.Jupyter_VPython = "/lab/extensions/vpython/static/vpython_data/" // prefix used by glow.min.js for textures
+//var datadir = '/lab/extensions/vpython/static/vpython_data/'
+//window.Jupyter_VPython = "/lab/extensions/vpython/static/vpython_data/" // prefix used by glow.min.js for textures
+var url = new URL(img);
+var datadir = url.pathname.substring(0, url.pathname.lastIndexOf('/')) + "/vpython_data/";
+window.Jupyter_VPython = datadir // prefix used by glow.min.js for textures
+url = null
 
 function fontloading() {
     "use strict";
@@ -101,7 +109,6 @@ function fontloading() {
         })
     }
 	if (window.__font_serif === undefined) {
-		try{
         var fserif = datadir+'NimbusRomNo9L-Med.otf'
         opentype_load(fserif, function(err, fontrefserif) {
             if (err) {
@@ -111,9 +118,6 @@ function fontloading() {
                 console.log('SERIF FONT LOADED')
             }
         })
-		} catch(err) {
-			console.log(err)
-		}
     }
 }
 fontloading()
@@ -206,7 +210,7 @@ cylinder = vp_cylinder
 pyramid = vp_pyramid
 cone = vp_cone
 helix = vp_helix
-//ellipsoid = vp_ellipsoid
+//ellipsoid = vp_ellipsoid   // This line causes a big problem in jupyterlab vpython extension
 ring = vp_ring
 arrow = vp_arrow
 compound = vp_compound
@@ -1046,4 +1050,4 @@ function handle_attrs(dattrs) {
 }
 console.log("END OF GLOWCOMM")
 
-//});
\ No newline at end of file
+//});
